@@ -1,4 +1,4 @@
-package oo_sub v1.0.8;
+package oo_sub v1.0.9;
 
 use strict;   # https://perldoc.perl.org/strict
 use warnings; # https://perldoc.perl.org/warnings
@@ -47,7 +47,7 @@ for my $module ( @modules ) {
 
 =head1 NAME
 
-oo_sub - Use object-oriented versions of built-in Perl functions
+oo_sub - Use object-oriented versions of Perl built-in functions
 
 =head1 SYNOPSIS
 
@@ -59,9 +59,12 @@ oo_sub - Use object-oriented versions of built-in Perl functions
   my $group = getgrgid 0;
   say $group -> name; # use feature 'say';
 
-  say my $file = stat '.' -> ino;
+  say my $file =
+    stat ('.') -> ino;
 
-  printf "%s: %s", getprotobyname 'tcp' -> proto, getservbyname 'ftp' -> port;
+  printf "%s: %s",
+    getprotobyname ('tcp') -> proto,
+    getservbyname ('ftp') -> port;
 
   say Dumper getnetbyname 'loopback'; # use Data::Dumper;
 
